import React from 'react';
import Header from '@/components/Header';
import ExperimentGrid from '@/components/lab/ExperimentGrid';
import LabHeader from '@/components/lab/LabHeader';
import LabFilters from '@/components/lab/LabFilters';
import { useLabData } from '@/hooks/use-lab-data';
import { useLabFilters } from '@/hooks/use-lab-filters';
import AdminLabToolbar from '@/components/admin/AdminLabToolbar';
import { Route, Routes } from 'react-router-dom';
import AdminExperimentEdit from '@/pages/AdminExperimentEdit';
import { useQueryClient } from '@tanstack/react-query';
import { supabase } from '@/integrations/supabase/client';
import { useToast } from '@/components/ui/use-toast';

const Lab = () => {
  const { experiments, isLoading, profile, session, unlockedExperiments } = useLabData();
  const queryClient = useQueryClient();
  const { toast } = useToast();
  
  const {
    level,
    setLevel,
    category,
    setCategory,
    unlockedOnly,
    toggleUnlockedOnly,
    searchQuery,
    setSearchQuery,
    selectedLevel,
    setSelectedLevel,
    selectedCategory,
    setSelectedCategory,
    levels,
    categories
  } = useLabFilters();

  // Filter experiments based on the selected filters
  const filteredExperiments = experiments?.filter(experiment => {
    const levelMatches = level === '' || experiment.level === level;
    const categoryMatches = category === '' || experiment.category === category;
    // Only apply the unlockedOnly filter if the user is signed in
    const unlockedMatches = !session || !unlockedOnly || 
      unlockedExperiments.includes(experiment.id);
    
    return levelMatches && categoryMatches && unlockedMatches;
  });

  // Handler functions to adapt between the different parameter types
  const handleLevelChange = (level: string | null) => {
    setLevel(level || '');
  };

  const handleCategoryChange = (category: string | null) => {
    setCategory(category || '');
  };

  const handleDelete = async (id: string) => {
    try {
      // First delete all content associated with the experiment
      const { error: contentDeleteError } = await supabase
        .from('experiment_content')
        .delete()
        .eq('experiment_id', id);

      if (contentDeleteError) throw contentDeleteError;

      // Then delete any unlocks associated with the experiment
      const { error: unlocksDeleteError } = await supabase
        .from('user_experiments')
        .delete()
        .eq('experiment_id', id);

      if (unlocksDeleteError) throw unlocksDeleteError;

      // Finally delete the experiment itself
      const { error: experimentDeleteError } = await supabase
        .from('experiments')
        .delete()
        .eq('id', id);

      if (experimentDeleteError) throw experimentDeleteError;

      // Invalidate queries to refresh the UI
      await queryClient.invalidateQueries({
        predicate: (query) => 
          query.queryKey[0] === 'experiments' || 
          query.queryKey[0] === 'experiment-content' ||
          query.queryKey[0] === 'unlocked-experiments'
      });
      
      toast({
        title: "Success",
        description: "Experiment deleted successfully",
      });
    } catch (error) {
      console.error('Error deleting experiment:', error);
      toast({
        title: "Error",
        description: "Failed to delete experiment. Please try again.",
        variant: "destructive",
      });
    }
  };

  const isAdmin = !!profile?.is_admin;

  // Check if we're on an admin route
  const path = window.location.pathname;
  const isAdminRoute = path.startsWith('/admin/experiments/');
  
  if (isAdminRoute) {
    return (
      <div className="min-h-screen bg-background">
        <Header />
        <Routes>
          <Route path="/admin/experiments/:id/edit" element={<AdminExperimentEdit />} />
        </Routes>
      </div>
    );
  }

  return (
    <div className="min-h-screen bg-background">
      <Header />
      <main className="container mx-auto px-4 py-24">
        <LabHeader />
        
        <div className="mb-8">
          <LabFilters 
            searchQuery={searchQuery}
            setSearchQuery={setSearchQuery}
            selectedLevel={selectedLevel}
            setSelectedLevel={handleLevelChange}
            selectedCategory={selectedCategory}
            setSelectedCategory={handleCategoryChange}
            levels={levels}
            categories={categories}
          />
        </div>
        
        {isAdmin && (
          <div className="mb-6">
            <AdminLabToolbar isLoading={isLoading} />
          </div>
        )}
        
        <ExperimentGrid 
          experiments={filteredExperiments || []} 
          isLoading={isLoading} 
          isAdmin={isAdmin}
          onDelete={handleDelete}
          unlockedOnly={unlockedOnly && !!session}
          isAuthenticated={!!session}
        />
      </main>
    </div>
  );
};

export default Lab;
